@@ -6,13 +6,23 @@
 #'
 #' Missing values are replaced in atomic vectors; `NULL`s are replaced in lists.
 #'
-#' @inheritParams gather
+#' @section Grouped data frames:
+#' With grouped data frames created by [dplyr::group_by()], `fill()` will be
+#' applied _within_ each group, meaning that it won't fill across group
+#' boundaries. This can also be accomplished using the `.by` argument to
+#' `fill()`, which creates a temporary grouping for just this operation.
+#'
+#' @inheritParams dplyr::mutate
+#'
+#' @param data A data frame.
 #' @param ... <[`tidy-select`][tidyr_tidy_select]> Columns to fill.
 #' @param .direction Direction in which to fill missing values. Currently
 #'   either "down" (the default), "up", "downup" (i.e. first down and then up)
 #'   or "updown" (first up and then down).
+#'
 #' @export
 #' @examples
+#' # direction = "down" --------------------------------------------------------
 #' # Value (year) is recorded only when it changes
 #' sales <- tibble::tribble(
 #'   ~quarter, ~year, ~sales,
@@ -33,10 +43,10 @@
 #'   "Q3",      NA,    31768,
 #'   "Q4",      NA,    49094
 #' )
-#'
 #' # `fill()` defaults to replacing missing data from top to bottom
-#' sales %>% fill(year)
+#' sales |> fill(year)
 #'
+#' # direction = "up" ----------------------------------------------------------
 #' # Value (pet_type) is missing above
 #' tidy_pets <- tibble::tribble(
 #'   ~rank, ~pet_type, ~breed,
@@ -55,9 +65,10 @@
 #' )
 #'
 #' # For values that are missing above you can use `.direction = "up"`
-#' tidy_pets %>%
+#' tidy_pets |>
 #'   fill(pet_type, .direction = "up")
 #'
+#' # direction = "downup" ------------------------------------------------------
 #' # Value (n_squirrels) is missing above and below within a group
 #' squirrels <- tibble::tribble(
 #'   ~group,    ~name,     ~role,     ~n_squirrels,
@@ -75,22 +86,53 @@
 #'   3, "Danielle",    "Observer",   NA
 #' )
 #'
-#' # The values are inconsistently missing by position within the group
-#' # Use .direction = "downup" to fill missing values in both directions
-#' squirrels %>%
-#'   dplyr::group_by(group) %>%
-#'   fill(n_squirrels, .direction = "downup") %>%
-#'   dplyr::ungroup()
+#' # The values are inconsistently missing by position within the `group`.
+#' # Use `.direction = "downup"` to fill missing values in both directions
+#' # and `.by = group` to apply the fill per group.
+#' squirrels |>
+#'   fill(n_squirrels, .direction = "downup", .by = group)
 #'
-#' # Using `.direction = "updown"` accomplishes the same goal in this example
-fill <- function(data, ..., .direction = c("down", "up", "downup", "updown")) {
-  ellipsis::check_dots_unnamed()
+#' # If you want, you can also supply a data frame grouped with `group_by()`,
+#' # but don't forget to `ungroup()`!
+#' squirrels |>
+#'   dplyr::group_by(group) |>
+#'   fill(n_squirrels, .direction = "downup") |>
+#'   dplyr::ungroup()
+fill <- function(
+  data,
+  ...,
+  .by = NULL,
+  .direction = c("down", "up", "downup", "updown")
+) {
+  check_dots_unnamed()
   UseMethod("fill")
 }
 
 #' @export
-fill.data.frame <- function(data, ..., .direction = c("down", "up", "downup", "updown")) {
-  vars <- tidyselect::eval_select(expr(c(...)), data)
-  .direction <- arg_match0(.direction, values = c("down", "up", "downup", "updown"), arg_nm = ".direction")
-  dplyr::mutate_at(data, dplyr::vars(any_of(vars)), ~ vec_fill_missing(.x, direction = .direction))
+fill.data.frame <- function(
+  data,
+  ...,
+  .by = NULL,
+  .direction = c("down", "up", "downup", "updown")
+) {
+  vars <- names(tidyselect::eval_select(
+    expr = expr(c(...)),
+    data = data,
+    allow_rename = FALSE
+  ))
+
+  .direction <- arg_match0(
+    arg = .direction,
+    values = c("down", "up", "downup", "updown"),
+  )
+
+  fn <- function(col) {
+    vec_fill_missing(col, direction = .direction)
+  }
+
+  dplyr::mutate(
+    data,
+    dplyr::across(any_of(vars), .fns = fn),
+    .by = {{ .by }}
+  )
 }
